@@ -9,10 +9,15 @@
 (load-all-patches) ; Make sure all Lispworks patches are loaded
 
 (defconstant +site-config-file+
-  #P"/usr/lib/lispworks/lib/4-2-0-0/config/configure.lisp")
-   
-(when (probe-file +site-config-file+)
-  (load +site-config-file+))
+  #P"/usr/lib/lispworks43/lib/4-3-0-0/config/configure.lisp")
+
+(handler-case
+    (when (probe-file +site-config-file+)
+      (load +site-config-file+))
+  (error (e)
+    (format *debug-io* "Error loading site configuration file: ~A" e)
+    #+ignore (quit :status 1)
+    ))
    
 (handler-case
  (let ((import-file (environment-variable "CLC_IMPORT_FILE")))
@@ -24,14 +29,13 @@
 	(finish-output)
 	(quit :status 1)))
 
-(save-image #P"/usr/lib/lispworks/lw-gui.new"
+(save-image #P"/usr/lib/lispworks43/lw-gui.new"
 	    :environment t)
 
 (compile (defun lw-installer-restart ()
-	   #+unix (capi:ensure-motif-libraries)
 	   (mp:initialize-multiprocessing)))
 
-(save-image #P"/usr/lib/lispworks/lw-console.new"
+(save-image #P"/usr/lib/lispworks43/lw-console.new"
 	    :restart-function 'lw-installer-restart 
 	    :environment nil
 	    :multiprocessing nil
